<?php if ( ! defined( 'ABSPATH' ) ) { die( 'Direct access forbidden.' ); }
/**
 * Theme Configuration and Custom CSS initializtion
 */


/**
 * Global theme config for header/footer/sections
 */
if ( !function_exists('holamed_theme_config') ) {

	add_filter( 'ltx_get_theme_config', 'holamed_theme_config', 10, 1 );
	function holamed_theme_config() {

	    return array(
	    	'navbar'	=>	array(
				'white'  	=> esc_html__( 'Default. White Background', 'holamed' ),
				'white-border'  	=> esc_html__( 'With bottom border and search. White Background', 'holamed' ),
				'transparent'	=> esc_html__( 'Homepage. Transparent Black', 'holamed' ),
			),
			'navbar-default' => 'white',

			'footer' => array(
				'default'  => esc_html__( 'Default', 'holamed' ),		
			),
			'footer-default' => 'default',
		);
	}
}


/**
 * Config used for lt-ext plugin to set Visual Composer configuration
 */
if ( !function_exists('holamed_vc_config') ) {

	add_filter( 'ltx_get_vc_config', 'holamed_vc_config', 10, 1 );
	function holamed_vc_config( $value ) {

	    return array(
	    	'sections'	=>	array(
				esc_html__("Displaced floating section", 'holamed') 		=> "displaced-top",				
				esc_html__("Diagnostic Icons", 'holamed') 		=> "ltx-diag-icons",
				esc_html__("Surgery Services", 'holamed') 		=> "ltx-surg-services",
				esc_html__("Massage Technics", 'holamed') 		=> "ltx-massage-technics",
				esc_html__("Subscribe Block", 'holamed') 		=> "ltx-subscribe-block",
			),
			'background' => array(
				esc_html__( "Main Color", 'holamed' ) => "theme_color",
				esc_html__( "Second Color", 'holamed' ) => "second",			
				esc_html__( "Gray", 'holamed' ) => "gray",
				esc_html__( "White", 'holamed' ) => "white",
				esc_html__( "Black", 'holamed' ) => "black",			
			),
			'overlay'	=> array(
				esc_html__( "Black Overlay (50%)", 'holamed' ) => "black",
				esc_html__( "Dark Overlay (90%)", 'holamed' ) => "dark",
				esc_html__( "White Overlay", 'holamed' ) => "white",
				esc_html__( "Waves Overlay", 'holamed' ) => "waves",
			),
		);
	}
}


/*
* Adding additional TinyMCE options
*/
if ( !function_exists('holamed_mce_before_init_insert_formats') ) {

	add_filter('mce_buttons_2', 'holamed_wpb_mce_buttons_2');
	function holamed_wpb_mce_buttons_2( $buttons ) {

	    array_unshift($buttons, 'styleselect');
	    return $buttons;
	}

	add_filter( 'tiny_mce_before_init', 'holamed_mce_before_init_insert_formats' );
	function holamed_mce_before_init_insert_formats( $init_array ) {  

	    $style_formats = array(

	        array(  
	            'title' => esc_html__('Main Color', 'holamed'),
	            'block' => 'span',  
	            'classes' => 'color-main',
	            'wrapper' => true,
	        ),  
	        array(  
	            'title' => esc_html__('Second Color', 'holamed'),
	            'block' => 'span',  
	            'classes' => 'color-second',
	            'wrapper' => true,
	        ),
	        array(  
	            'title' => esc_html__('White Color', 'holamed'),
	            'block' => 'span',  
	            'classes' => 'color-white',
	            'wrapper' => true,   
	        ),
	        array(  
	            'title' => esc_html__('Large Text', 'holamed'),
	            'block' => 'span',  
	            'classes' => 'text-lg',
	            'wrapper' => true,
	        ),    
	        array(  
	            'title' => esc_html__('Line Height Double', 'holamed'),
	            'block' => 'span',  
	            'classes' => 'line-height-2',
	            'wrapper' => true,
	        ),         
	        array(  
	            'title' => 'List Checkbox',
	            'selector' => 'ul',
	            'classes' => 'check',
	        ),          
	        array(  
	            'title' => 'List Plus',
	            'selector' => 'ul',
	            'classes' => 'ltx-plus',
	        ),          

	    );  
	    $init_array['style_formats'] = json_encode( $style_formats );  
	     
	    return $init_array;  
	} 
}


/**
 * Register widget areas.
 *
 */
if ( !function_exists('holamed_action_theme_widgets_init') ) {

	add_action( 'widgets_init', 'holamed_action_theme_widgets_init' );
	function holamed_action_theme_widgets_init() {

		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar Default', 'holamed' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Displayed in the right/left section of the site.', 'holamed' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="header-widget">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar WooCommerce', 'holamed' ),
			'id'            => 'sidebar-wc',
			'description'   => esc_html__( 'Displayed in the right/left section of the site.', 'holamed' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="header-widget">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Footer 1', 'holamed' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Displayed in the footer section of the site.', 'holamed' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="header-widget">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer 2', 'holamed' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Displayed in the footer section of the site.', 'holamed' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="header-widget">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer 3', 'holamed' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Displayed in the footer section of the site.', 'holamed' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="header-widget">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer 4', 'holamed' ),
			'id'            => 'footer-4',
			'description'   => esc_html__( 'Displayed in the footer section of the site.', 'holamed' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="header-widget">',
			'after_title'   => '</h4>',
		) );			

	}
}



/**
 * Additional styles init
 */
if ( !function_exists('holamed_css_style') ) {

	add_action( 'wp_enqueue_scripts', 'holamed_css_style', 10 );
	function holamed_css_style() {

		global $wp_query;

		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap-grid.css', array(), '1.0' );

		wp_enqueue_style( 'holamed-plugins-css', get_template_directory_uri() . '/assets/css/plugins.css', array(), wp_get_theme()->get('Version') );

		wp_enqueue_style( 'holamed-theme-style', get_stylesheet_uri(), array( 'bootstrap', 'holamed-plugins-css' ), wp_get_theme()->get('Version') );
	}
}


/**
 * Wp-admin styles and scripts
 */
if ( !function_exists('holamed_admin_init') ) {

	add_action( 'after_setup_theme', 'holamed_admin_init' );
	function holamed_admin_init() {

		add_action("admin_enqueue_scripts", 'holamed_admin_scripts');
	}

	function holamed_admin_scripts() {

		if ( function_exists('fw_get_db_settings_option') ) {

			$fontello['css'] = fw_get_db_settings_option( 'fontello-css' );
			$fontello['eot'] = fw_get_db_settings_option( 'fontello-eot' );
			$fontello['ttf'] = fw_get_db_settings_option( 'fontello-ttf' );
			$fontello['woff'] = fw_get_db_settings_option( 'fontello-woff' );
			$fontello['woff2'] = fw_get_db_settings_option( 'fontello-woff2' );
			$fontello['svg'] = fw_get_db_settings_option( 'fontello-svg' );


			wp_deregister_style( 'font-awesome' );
			wp_enqueue_style(  'font-awesome',  get_template_directory_uri().'/assets/fonts/font-awesome/css/all.min.css', array(), wp_get_theme()->get('Version') );
			wp_enqueue_style(  'font-awesome-shims',  get_template_directory_uri().'/assets/fonts/font-awesome/css/v4-shims.min.css', array(), wp_get_theme()->get('Version') );


			if ( !empty($fontello['css']) AND !empty( $fontello['eot']) AND  !empty( $fontello['ttf']) AND  !empty( $fontello['woff']) AND  !empty( $fontello['woff2']) AND  !empty( $fontello['svg']) ) {

				wp_enqueue_style(  'holamed-fontello',  $fontello['css']['url'], array(), wp_get_theme()->get('Version') );

				$randomver = wp_get_theme()->get('Version');
				$css_content = "@font-face {
				font-family: 'holamed-fontello';
				  src: url('". esc_url ( $fontello['eot']['url']. "?" . $randomver )."');
				  src: url('". esc_url ( $fontello['eot']['url']. "?" . $randomver )."#iefix') format('embedded-opentype'),
				       url('". esc_url ( $fontello['woff2']['url']. "?" . $randomver )."') format('woff2'),
				       url('". esc_url ( $fontello['woff']['url']. "?" . $randomver )."') format('woff'),
				       url('". esc_url ( $fontello['ttf']['url']. "?" . $randomver )."') format('truetype'),
				       url('". esc_url ( $fontello['svg']['url']. "?" . $randomver )."#" . pathinfo(wp_basename( $fontello['svg']['url'] ), PATHINFO_FILENAME)  . "') format('svg');
				  font-weight: normal;
				  font-style: normal;
				}";

				wp_add_inline_style( 'holamed-fontello', $css_content );
			}

			wp_enqueue_script( 'holamed-theme-admin', get_template_directory_uri() . '/assets/js/scripts-admin.js', array( 'jquery' ) );
		}
	}
}




