<?php if ( ! defined( 'ABSPATH' ) ) { die( 'Direct access forbidden.' ); }
/**
 * Generating inline css styles for customization
 */

if ( !function_exists('holamed_generate_css') ) {

	function holamed_generate_css() {

		global $wp_query;

		// List of attributes
		$css = array(
			'main_color' 			=> true,
			'second_color' 			=> true,			
			'second_lighter_color' 			=> true,			
			'gray_color' 			=> true,
			'white_color' 			=> true,
			'black_color' 			=> true,			
			'red_color' 			=> true,			
			'footer_color' 			=> true,			

			'nav_bg' 				=> true,
			'nav_opacity_top' 		=> true,
			'nav_opacity_scroll'	=> true,

			'border_radius' 		=> true,
		);

		// Escaping all the attributes
		$css_rgb = array();
		foreach ($css as $key => $item) {

			$css[$key] = esc_attr(fw_get_db_customizer_option($key));
			$css_rgb[$key] = sscanf(esc_attr(fw_get_db_customizer_option($key)), "#%02x%02x%02x");
		}

		// Setting different color scheme for page
		if ( function_exists( 'FW' ) ) {

			$holamed_color_schemes = array();
			$holamed_color_schemes_ = fw_get_db_settings_option( 'items' );

			if ( !empty($holamed_color_schemes_) ) {
				foreach ($holamed_color_schemes_ as $v) {

					$holamed_color_schemes[$v['slug']] = $v;
				}			
			}
		}

		$holamed_current_scheme =  apply_filters('holamed_current_scheme', array());	
		if ($holamed_current_scheme == 'default' OR empty($holamed_current_scheme)) $holamed_current_scheme = 1;

		if ( function_exists( 'FW' ) AND !empty($holamed_current_scheme) ) {

			foreach (array(
					'main_color' => 'main-color',
					'second_color' => 'second-color',
					'gray_color' => 'gray-color',
					'black_color' => 'black-color') as $k => $v) {

				if ( !empty($holamed_color_schemes[$holamed_current_scheme][$v]) ) {

					$css[$k] = esc_attr($holamed_color_schemes[$holamed_current_scheme][$v]);
					$css_rgb[$k] = sscanf(esc_attr($holamed_color_schemes[$holamed_current_scheme][$v]), "#%02x%02x%02x");
				}
			}
		}

		$css['main_darker_color'] = holamed_adjustBrightness($css['main_color'], -30);
		$css['main_lighter_color'] = holamed_adjustBrightness($css['main_color'], 30);

		include get_template_directory() . '/inc/theme-style/google-fonts.php';		

		$theme_style = "";

		$theme_style .= "
			:root {
			  --black:  {$css['black_color']} !important;
			  --black-text:  rgba({$css_rgb['black_color'][0]},{$css_rgb['black_color'][1]},{$css_rgb['black_color'][2]},.75) !important;
			  --black-light:  rgba({$css_rgb['black_color'][0]},{$css_rgb['black_color'][1]},{$css_rgb['black_color'][2]},.1) !important;
			  --gray:   {$css['gray_color']} !important;
			  --white:  {$css['white_color']} !important;
			  --main:   {$css['main_color']} !important;
			  --main-darker: {$css['main_darker_color']} !important;
			  --main-semi:  rgba({$css_rgb['main_color'][0]},{$css_rgb['main_color'][1]},{$css_rgb['main_color'][2]},.5) !important;
			  --second:   {$css['second_color']} !important;
			  --red:   {$css['red_color']} !important;

			  --font-main:   '{$css['font_main']}' !important;
			  --font-headers: '{$css['font_headers']}' !important;
			}		
		";


		/**
		 * Theme Specific inline styles
		 */
		if ( function_exists( 'FW' ) ) {

			$heading_bg = fw_get_db_settings_option( 'heading_bg' );
			if (! empty( $heading_bg ) ) {

				$theme_style .= '.heading.bg-image { background-image: url(' . esc_url( $heading_bg['url'] ) . ') !important; } ';
			}

			$header_bg = fw_get_db_settings_option( 'header_bg' );

			$featured_bg = fw_get_db_settings_option( 'featured_bg' );
			if (! empty( $header_bg ) OR $featured_bg == 'enabled'  ) {

				if ( has_post_thumbnail() && $featured_bg == 'enabled') {

					$theme_style .= '.page-header { background-image: url(' . esc_url( get_the_post_thumbnail_url( $wp_query->get_queried_object_id(), 'full') ) . ') !important; } ';
				}
					else
				if ( !empty( $header_bg['url'] ) ) {

					$theme_style .= '.page-header { background-image: url(' . esc_url( $header_bg['url'] ) . ') !important; } ';
				}
			}

			if ( ( get_post_type() == 'team' ) ) {

				$image = fw_get_db_post_option(get_The_ID(), 'image');

				if ( !empty($image) ) {

					$theme_style .= '.page-header { background-image: url(' . esc_url( $image['url'] ) . ') !important; } ';
				}
			}

			$header_overlay = fw_get_db_settings_option( 'header_overlay' );
			$header_overlay_position = fw_get_db_settings_option( 'header_overlay_position' );
			if (! empty( $header_overlay ) ) {

				$theme_style .= '.page-header::after { background-image: url(' . esc_url( $header_overlay['url'] ) . ') !important; } ';
			}

			$theme_icon = fw_get_db_settings_option( 'theme-icon-main' );
			if (! empty( $theme_icon ) ) {

				$theme_style .= '.theme-icon-main { background-image: url(' . esc_url( $theme_icon['url'] ) . ') !important; } ';
				$theme_style .= '.woocommerce-MyAccount-navigation .header-widget:before, .widget-area .header-widget:before { background-image: url(' . esc_url( $theme_icon['url'] ) . ') !important; } ';				
			}

			$theme_icon_second = fw_get_db_settings_option( 'theme-icon-second' );
			if (! empty( $theme_icon_second ) ) {

				$theme_style .= '.woocommerce-MyAccount-navigation .header-widget, .widget-area .header-widget, .theme-icon-second { background-image: url(' . esc_url( $theme_icon_second['url'] ) . ') !important; } ';
			}

			$footer_bg = fw_get_db_settings_option( 'footer_bg' );
			if (! empty( $footer_bg ) ) {

				$theme_style .= '#ltx-widgets-footer::before { background-image: url(' . esc_url( $footer_bg['url'] ) . ') !important; } ';
			}

			$go_top_img = fw_get_db_settings_option( 'go_top_img' );
			if (! empty( $go_top_img ) ) {

				$theme_style .= '.go-top:before { background-image: url(' . esc_url( $go_top_img['url'] ) . ') !important; } ';
			}

			$nav_opacity = fw_get_db_customizer_option('nav_opacity');
			if ( isset($nav_opacity) ) {

				$theme_style .= '#nav-wrapper.navbar-layout-transparent nav.navbar { background-color: rgba('.esc_attr($css_rgb['black_color'][0]).', '.esc_attr($css_rgb['black_color'][1]).', '.esc_attr($css_rgb['black_color'][2]).', '.esc_attr($nav_opacity).'); } ';							
			}

			$nav_opacity_scroll = fw_get_db_customizer_option('nav_opacity_scroll');
			if ( isset($nav_opacity_scroll) ) {

				$theme_style .= '#nav-wrapper.navbar-layout-transparent nav.navbar.darkest { background-color: rgba('.esc_attr($css_rgb['black_color'][0]).', '.esc_attr($css_rgb['black_color'][1]).', '.esc_attr($css_rgb['black_color'][2]).', '.esc_attr($nav_opacity_scroll).'); } ';			
			}

			$logo_height = fw_get_db_customizer_option('logo_height');
			if ( !empty($logo_height) ) {

				$theme_style .= '#nav-wrapper nav.navbar .navbar-logo .logo img { max-height: '.esc_attr($logo_height).'px; } ';
			}

			$pace = fw_get_db_settings_option( 'page-loader' );
			if ( !empty($pace) AND !empty($pace['image']) AND !empty($pace['image']['loader_img'])) {

				wp_add_inline_style( 'holamed-theme-style', '.paceloader-image .pace-image { background-image: url(' . esc_attr( $pace['image']['loader_img']['url'] ) . ') !important; } ' );
			}
			
			$fontello['css'] = fw_get_db_settings_option( 'fontello-css' );
			$fontello['eot'] = fw_get_db_settings_option( 'fontello-eot' );
			$fontello['ttf'] = fw_get_db_settings_option( 'fontello-ttf' );
			$fontello['woff'] = fw_get_db_settings_option( 'fontello-woff' );
			$fontello['woff2'] = fw_get_db_settings_option( 'fontello-woff2' );
			$fontello['svg'] = fw_get_db_settings_option( 'fontello-svg' );

			if ( !empty($fontello['css']) AND !empty( $fontello['eot']) AND  !empty( $fontello['ttf']) AND  !empty( $fontello['woff']) AND  !empty( $fontello['woff2']) AND  !empty( $fontello['svg']) ) {

				$randomver = wp_get_theme()->get('Version');
				$css_content = "@font-face {
				font-family: 'holamed-fontello';
				  src: url('". esc_url ( $fontello['eot']['url']. "?" . $randomver )."');
				  src: url('". esc_url ( $fontello['eot']['url']. "?" . $randomver )."#iefix') format('embedded-opentype'),
				       url('". esc_url ( $fontello['woff2']['url']. "?" . $randomver )."') format('woff2'),
				       url('". esc_url ( $fontello['woff']['url']. "?" . $randomver )."') format('woff'),
				       url('". esc_url ( $fontello['ttf']['url']. "?" . $randomver )."') format('truetype'),
				       url('". esc_url ( $fontello['svg']['url']. "?" . $randomver )."#" . pathinfo(wp_basename( $fontello['svg']['url'] ), PATHINFO_FILENAME)  . "') format('svg');
				  font-weight: normal;
				  font-style: normal;
				}";

				wp_add_inline_style( 'holamed-theme-style', $css_content );
				wp_enqueue_style(  'holamed-fontello',  $fontello['css']['url'], array(), wp_get_theme()->get('Version') );
			}
		}

		$theme_style = str_replace( array( "\n", "\r" ), '', $theme_style );

		return $theme_style;
	}
}
